@@ -1,5 +1,4 @@
 import collections
-import operator
 
 from .cache import Cache
 
@@ -13,12 +12,12 @@ class LFUCache(Cache):
 
     def __getitem__(self, key, cache_getitem=Cache.__getitem__):
         value = cache_getitem(self, key)
-        self.__counter[key] += 1
+        self.__counter[key] -= 1
         return value
 
     def __setitem__(self, key, value, cache_setitem=Cache.__setitem__):
         cache_setitem(self, key, value)
-        self.__counter[key] += 1
+        self.__counter[key] -= 1
 
     def __delitem__(self, key, cache_delitem=Cache.__delitem__):
         cache_delitem(self, key)
@@ -27,7 +26,8 @@ class LFUCache(Cache):
     def popitem(self):
         """Remove and return the `(key, value)` pair least frequently used."""
         try:
-            key = min(self.__counter.items(), key=operator.itemgetter(1))[0]
+            (key, _), = self.__counter.most_common(1)
         except ValueError:
-            raise KeyError('cache is empty')
-        return key, self.pop(key)
+            raise KeyError('%s is empty' % self.__class__.__name__)
+        else:
+            return (key, self.pop(key))
